Enum globset::Error
[−]
[src]
pub enum Error {
InvalidRecursive,
UnclosedClass,
InvalidRange(char, char),
UnopenedAlternates,
UnclosedAlternates,
NestedAlternates,
Regex(String),
}Represents an error that can occur when parsing a glob pattern.
Variants
InvalidRecursiveOccurs when a use of ** is invalid. Namely, ** can only appear
adjacent to a path separator, or the beginning/end of a glob.
UnclosedClassOccurs when a character class (e.g., [abc]) is not closed.
InvalidRange(char, char)Occurs when a range in a character (e.g., [a-z]) is invalid. For
example, if the range starts with a lexicographically larger character
than it ends with.
UnopenedAlternatesOccurs when a } is found without a matching {.
UnclosedAlternatesOccurs when a { is found without a matching }.
NestedAlternatesOccurs when an alternating group is nested inside another alternating
group, e.g., {{a,b},{c,d}}.
Regex(String)An error associated with parsing or compiling a regex.