Enum ErrorKind
enum ErrorKind
The kind of error that can occur when parsing a glob pattern.
Variants
-
InvalidRecursive DEPRECATED.
This error used to occur for consistency with git's glob specification, but the specification now accepts all uses of
**. When**does not appear adjacent to a path separator or at the beginning/end of a glob, it is now treated as two consecutive*patterns. As such, this error is no longer used.-
UnclosedClass Occurs when a character class (e.g.,
[abc]) is not closed.-
InvalidRange(char, char) Occurs when a range in a character (e.g.,
[a-z]) is invalid. For example, if the range starts with a lexicographically larger character than it ends with.-
UnopenedAlternates Occurs when a
}is found without a matching{.-
UnclosedAlternates Occurs when a
{is found without a matching}.-
NestedAlternates DEPRECATED.
This error used to occur when an alternating group was nested inside another alternating group, e.g.,
{{a,b},{c,d}}. However, this is now supported and as such this error cannot occur.-
DanglingEscape Occurs when an unescaped '' is found at the end of a glob.
-
Regex(String) An error associated with parsing or compiling a regex.
Implementations
impl Clone for ErrorKind
fn clone(self: &Self) -> ErrorKind
impl Debug for ErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ErrorKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for ErrorKind
impl Freeze for ErrorKind
impl PartialEq for ErrorKind
fn eq(self: &Self, other: &ErrorKind) -> bool
impl RefUnwindSafe for ErrorKind
impl Send for ErrorKind
impl StructuralPartialEq for ErrorKind
impl Sync for ErrorKind
impl Unpin for ErrorKind
impl UnsafeUnpin for ErrorKind
impl UnwindSafe for ErrorKind
impl<T> Any for ErrorKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ErrorKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ErrorKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ErrorKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ErrorKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ErrorKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for ErrorKind
fn to_string(self: &Self) -> String
impl<T, U> Into for ErrorKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ErrorKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ErrorKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>