Struct globset::Error [−][src]
pub struct Error { /* fields omitted */ }Represents an error that can occur when parsing a glob pattern.
Methods
impl Error[src]
impl Errorpub fn glob(&self) -> Option<&str>[src]
pub fn glob(&self) -> Option<&str>Return the glob that caused this error, if one exists.
pub fn kind(&self) -> &ErrorKind[src]
pub fn kind(&self) -> &ErrorKindReturn the kind of this error.