Struct GlobMatcher

struct GlobMatcher { ... }

A matcher for a single pattern.

Implementations

impl GlobMatcher

fn is_match<P: AsRef<Path>>(self: &Self, path: P) -> bool

Tests whether the given path matches this pattern or not.

fn is_match_candidate(self: &Self, path: &Candidate<'_>) -> bool

Tests whether the given path matches this pattern or not.

fn glob(self: &Self) -> &Glob

Returns the Glob used to compile this matcher.

impl Clone for GlobMatcher

fn clone(self: &Self) -> GlobMatcher

impl Debug for GlobMatcher

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for GlobMatcher

impl RefUnwindSafe for GlobMatcher

impl Send for GlobMatcher

impl Sync for GlobMatcher

impl Unpin for GlobMatcher

impl UnsafeUnpin for GlobMatcher

impl UnwindSafe for GlobMatcher

impl<T> Any for GlobMatcher

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GlobMatcher

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GlobMatcher

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for GlobMatcher

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for GlobMatcher

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for GlobMatcher

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for GlobMatcher

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GlobMatcher

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GlobMatcher

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>