ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind { InvalidRecursive, UnclosedClass, InvalidRange(char, char), UnopenedAlternates, UnclosedAlternates, NestedAlternates, DanglingEscape, Regex(String), }
The kind of error that can occur when parsing a glob pattern.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidRecursive

DEPRECATED.

This error used to occur for consistency with git’s glob specification, but the specification now accepts all uses of **. When ** does not appear adjacent to a path separator or at the beginning/end of a glob, it is now treated as two consecutive * patterns. As such, this error is no longer used.



UnclosedClass

Occurs when a character class (e.g., [abc]) is not closed.



InvalidRange(char, char)

Occurs when a range in a character (e.g., [a-z]) is invalid. For example, if the range starts with a lexicographically larger character than it ends with.



UnopenedAlternates

Occurs when a } is found without a matching {.



UnclosedAlternates

Occurs when a { is found without a matching }.



NestedAlternates

DEPRECATED.

This error used to occur when an alternating group was nested inside another alternating group, e.g., {{a,b},{c,d}}. However, this is now supported and as such this error cannot occur.



DanglingEscape

Occurs when an unescaped ’' is found at the end of a glob.



Regex(String)

An error associated with parsing or compiling a regex.