[−][src]Enum globset::ErrorKind
The kind of error that can occur when parsing a glob pattern.
Variants
InvalidRecursiveDEPRECATED.
This error used to occur for consistency with git's glob specification,
but the specification now accepts all uses of **. When ** does not
appear adjacent to a path separator or at the beginning/end of a glob,
it is now treated as two consecutive * patterns. As such, this error
is no longer used.
UnclosedClassOccurs when a character class (e.g., [abc]) is not closed.
InvalidRange(char, char)Occurs when a range in a character (e.g., [a-z]) is invalid. For
example, if the range starts with a lexicographically larger character
than it ends with.
UnopenedAlternatesOccurs when a } is found without a matching {.
UnclosedAlternatesOccurs when a { is found without a matching }.
NestedAlternatesOccurs when an alternating group is nested inside another alternating
group, e.g., {{a,b},{c,d}}.
DanglingEscapeOccurs when an unescaped '' is found at the end of a glob.
Regex(String)An error associated with parsing or compiling a regex.