Struct Candidate
struct Candidate<'a> { ... }
A candidate path for matching.
All glob matching in this crate operates on Candidate values.
Constructing candidates has a very small cost associated with it, so
callers may find it beneficial to amortize that cost when matching a single
path against multiple globs or sets of globs.
Implementations
impl<'a> Candidate<'a>
fn new<P: AsRef<Path> + ?Sized>(path: &'a P) -> Candidate<'a>Create a new candidate for matching from the given path.
fn from_bytes<P: AsRef<[u8]> + ?Sized>(path: &'a P) -> Candidate<'a>Create a new candidate for matching from the given path as a sequence of bytes.
Generally speaking, this routine expects the bytes to be conventionally UTF-8. It is legal for the byte sequence to contain invalid UTF-8. However, if the bytes are in some other encoding that isn't ASCII compatible (for example, UTF-16), then the results of matching are unspecified.
impl<'a> Clone for Candidate<'a>
fn clone(self: &Self) -> Candidate<'a>
impl<'a> Debug for Candidate<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for Candidate<'a>
impl<'a> RefUnwindSafe for Candidate<'a>
impl<'a> Send for Candidate<'a>
impl<'a> Sync for Candidate<'a>
impl<'a> Unpin for Candidate<'a>
impl<'a> UnsafeUnpin for Candidate<'a>
impl<'a> UnwindSafe for Candidate<'a>
impl<T> Any for Candidate<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Candidate<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Candidate<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Candidate<'a>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Candidate<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Candidate<'a>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Candidate<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Candidate<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Candidate<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>