Struct GlobSetBuilder
struct GlobSetBuilder { ... }
GlobSetBuilder builds a group of patterns that can be used to simultaneously match a file path.
Implementations
impl GlobSetBuilder
fn new() -> GlobSetBuilderCreate a new
GlobSetBuilder. AGlobSetBuildercan be used to add new patterns. Once all patterns have been added,buildshould be called to produce aGlobSet, which can then be used for matching.fn build(self: &Self) -> Result<GlobSet, Error>Builds a new matcher from all of the glob patterns added so far.
Once a matcher is built, no new patterns can be added to it.
fn add(self: &mut Self, pat: Glob) -> &mut GlobSetBuilderAdd a new pattern to this set.
impl Clone for GlobSetBuilder
fn clone(self: &Self) -> GlobSetBuilder
impl Debug for GlobSetBuilder
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for GlobSetBuilder
impl RefUnwindSafe for GlobSetBuilder
impl Send for GlobSetBuilder
impl Sync for GlobSetBuilder
impl Unpin for GlobSetBuilder
impl UnsafeUnpin for GlobSetBuilder
impl UnwindSafe for GlobSetBuilder
impl<T> Any for GlobSetBuilder
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for GlobSetBuilder
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for GlobSetBuilder
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for GlobSetBuilder
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for GlobSetBuilder
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for GlobSetBuilder
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for GlobSetBuilder
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for GlobSetBuilder
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for GlobSetBuilder
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>